/**
 * Panel - Sensor Manager
 * @author www.pcsg.de (Henning Leutz)
 */

define('package/quiqqer/sensor/bin/SensorManager', [

    'qui/QUI',
    'qui/controls/desktop/Panel',
    'qui/controls/windows/Confirm',
    'qui/controls/buttons/Button',
    'qui/controls/buttons/Seperator',
    'controls/grid/Grid',
    'Ajax',
    'Locale'

], function(QUI, QUIPanel, QUIConfirm, QUIButton, QUIButtonSeperator, Grid, Ajax, Locale)
{
    "use strict";

    return new Class({

        Extends : QUIPanel,
        Type    : 'package/quiqqer/sensor/bin/SensorManager',

        Binds : [
            '$onCreate'
        ],

        options : {
            icon  : 'icon-stethoscope',
            title : 'Sensor-Manager'
        },

        initialize : function(options)
        {
            this.parent( options );

            this.$Grid = null;

            this.addEvents({
                onCreate : this.$onCreate,
                onResize : this.$onResize
            });
        },

        /**
         * Load the sensor list into the grid
         *
         * @return {self}
         */
        loadList : function()
        {
            var self = this;

            Ajax.get('package_quiqqer_sensor_ajax_list', function(result)
            {
                if ( !self.$Grid ) {
                    return;
                }

                self.$Grid.setData({
                    data : result
                });

            }, {
                'package' : 'quiqqer/sensor'
            });

            return this;
        },

        /**
         * Event : on create
         */
        $onCreate : function()
        {
            var self = this;

            this.addButton({
                text : 'Sensor hinzufügen',
                textimage : 'icon-plus',
                events :
                {
                    onClick : function() {
                        self.openAddSensorWindow();
                    }
                }
            });

            this.addButton( new QUIButtonSeperator() );

            this.addButton(
                new QUIButton({
                    name : 'edit',
                    text : 'Markierten Sensor editieren',
                    textimage : 'icon-pencil',
                    events :
                    {
                        onClick : function() {
                            self.editMarkedSensor();
                        }
                    }
                })
            );

            this.addButton({
                name : 'delete',
                text : 'Markierte Sensoren löschen',
                textimage : 'icon-trash',
                events :
                {
                    onClick : function() {
                        self.deleteMarkedSensors();
                    }
                },
                disabled : true
            });

            var Content   = this.getContent(),
                size      = Content.getSize(),

                Container = new Element('div', {
                    'class' : 'box',
                    styles : {
                        width : '100%',
                        height : '100%'
                    }
                }).inject( Content );


            this.$Grid = new Grid(Container, {
                columnModel : [{
                    header    : 'ID',
                    dataIndex : 'id',
                    dataType  : 'string',
                    width     : 50
                }, {
                    header    : 'Sensor-Type',
                    dataIndex : 'sensorType',
                    dataType  : 'string',
                    width     : 150
                }, {
                    header    : 'Sensor-Pin',
                    dataIndex : 'sensorPin',
                    dataType  : 'string',
                    width     : 150
                }, {
                    header    : 'Title',
                    dataIndex : 'title',
                    dataType  : 'string',
                    width     : 150
                }],
                multipleSelection : true,
                pagination : true
            });

            this.$Grid.addEvents({
                onRefresh : function() {
                    self.loadList();
                },
                onClick : function()
                {
                    var delButton  = self.getButtons( 'delete' ),
                        editButton = self.getButtons( 'edit' ),
                        selected   = self.$Grid.getSelectedIndices().length;

                    if ( selected == 1 )
                    {
                        editButton.enable();
                    } else
                    {
                        editButton.disable();
                    }

                    if ( selected )
                    {
                        delButton.enable();
                    } else
                    {
                        delButton.disable()
                    }
                },

                onDblClick : function(data)
                {
                    var rowData = self.$Grid.getDataByRow( data.row );

                    self.editSensor( rowData.id );
                }
            });

            this.loadList();
        },

        /**
         * event : on resize
         */
        $onResize : function()
        {
            if ( !this.$Grid ) {
                return;
            }

            var Content = this.getContent(),
                size    = Content.getSize();

            this.$Grid.setHeight( size.y - 40 );
            this.$Grid.setWidth( size.x - 40 );
        },

        /**
         * Open the delete marked sensor windows and delete all marked sensors
         *
         * @return {self}
         */
        deleteMarkedSensors : function()
        {
            if ( !this.$Grid ) {
                return this;
            }

            var self = this,
                data = this.$Grid.getSelectedData();

            if ( !data.length ) {
                return this;
            }

            var ids = data.map(function(o) {
                return o.id;
            });

            new QUIConfirm({
                icon  : 'icon-remove',
                title : 'Sensoren Einträge löschen',
                text  : '<p>Möchten Sie folgende Sensoren wirklich löschen?</p>',
                information : '<p>Zu löschende Sensoren-Einträge: <b>'+ ids.join(',') +'</b></p>' +
                              '<p>Beachten Sie, die Sensoren-Einträge und die Sensorendaten sind nicht wieder herstellbar</p>',
                events :
                {
                    onSubmit : function(Win)
                    {
                        Win.Loader.show();

                        Ajax.post('package_quiqqer_sensor_ajax_delete', function()
                        {
                            Win.close();
                            self.loadList();
                        }, {
                            'package' : 'quiqqer/sensor',
                            ids : JSON.encode( ids )
                        });
                    }
                }
            }).open();

            return this;
        },

        /**
         * Edit a sensor, opens the sensor Edit-Window
         *
         * @param {String} sensorId - ID of the Sensor
         */
        editSensor : function(sensorId)
        {
            var self = this;

            require(['package/quiqqer/sensor/bin/SensorSettingWindow'], function(Window)
            {
                 new Window({
                     sensorId : sensorId,
                     events :
                     {
                         onSubmit : function() {
                             self.loadList();
                         }
                     }
                 }).open();
            });

            return this;
        },

        /**
         * Opens the Edit-Window for the marked sensor
         */
        editMarkedSensor : function()
        {
            if ( !this.$Grid ) {
                return this;
            }

            var self = this,
                data = this.$Grid.getSelectedData();

            if ( !data.length ) {
                return this;
            }

            this.editSensor( data[ 0 ].id );
        },

        /**
         * Open the add Sensor-Window
         *
         * @return {self}
         */
        openAddSensorWindow : function()
        {
            var self = this;

            require(['package/quiqqer/sensor/bin/SensorSettingWindow'], function(Window)
            {
                 new Window({
                     events :
                     {
                         onSubmit : function() {
                             self.loadList();
                         }
                     }
                 }).open();
            });

            return this;
        }
    });

});